@@ -231,7 +231,7 @@ def zones_logpush(self):
     self.add('VOID', 'zones', 'logpush/datasets')
     self.add('AUTH', 'zones', 'logpush/datasets', 'fields')
     self.add('AUTH', 'zones', 'logpush/datasets', 'jobs')
-    self.add('VOID', 'zones', 'logpush/edge')
+    self.add('AUTH', 'zones', 'logpush/edge')
     self.add('AUTH', 'zones', 'logpush/edge/jobs')
     self.add('AUTH', 'zones', 'logpush/jobs')
     self.add('AUTH', 'zones', 'logpush/ownership')
@@ -383,11 +383,13 @@ def accounts(self):
     self.add('AUTH', 'accounts', 'cfd_tunnel')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'configurations')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'connections')
+    self.add('AUTH', 'accounts', 'cfd_tunnel', 'management')
     self.add('AUTH', 'accounts', 'cfd_tunnel', 'token')
     self.add('AUTH', 'accounts', 'custom_pages')
     self.add('VOID', 'accounts', 'dlp')
     self.add('VOID', 'accounts', 'dlp/patterns')
     self.add('AUTH', 'accounts', 'dlp/patterns/validate')
+    self.add('AUTH', 'accounts', 'dlp/payload_log')
     self.add('AUTH', 'accounts', 'dlp/profiles')
     self.add('AUTH', 'accounts', 'dlp/profiles/custom')
     self.add('AUTH', 'accounts', 'dlp/profiles/predefined')
@@ -433,8 +435,12 @@ def accounts(self):
     self.add('VOID', 'accounts', 'virtual_dns', 'dns_analytics')
     self.add('AUTH', 'accounts', 'virtual_dns', 'dns_analytics/report')
     self.add('AUTH', 'accounts', 'virtual_dns', 'dns_analytics/report/bytime')
+
     self.add('VOID', 'accounts', 'workers')
     self.add('AUTH', 'accounts', 'workers/account-settings')
+    self.add('VOID', 'accounts', 'workers/deployments')
+    self.add('AUTH', 'accounts', 'workers/deployments/by-script')
+    self.add('AUTH', 'accounts', 'workers/deployments/by-script', 'detail')
     self.add('VOID', 'accounts', 'workers/dispatch')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces')
     self.add('AUTH', 'accounts', 'workers/dispatch/namespaces', 'scripts')
@@ -464,7 +470,9 @@ def accounts_addressing(self):
     self.add('AUTH', 'accounts', 'addressing/prefixes')
     self.add('VOID', 'accounts', 'addressing/prefixes', 'bgp')
     self.add('AUTH', 'accounts', 'addressing/prefixes', 'bgp/status')
+    self.add('AUTH', 'accounts', 'addressing/prefixes', 'bindings')
     self.add('AUTH', 'accounts', 'addressing/prefixes', 'delegations')
+    self.add('AUTH', 'accounts', 'addressing/services')
 
 def accounts_audit_logs(self):
     """ accounts audit_logs """
@@ -549,6 +557,7 @@ def zones_access(self):
     self.add('AUTH', 'zones', 'access/apps', 'revoke_tokens')
     self.add('AUTH', 'zones', 'access/bookmarks')
     self.add('AUTH', 'zones', 'access/certificates')
+    self.add('AUTH', 'zones', 'access/certificates/settings')
 #   self.add('AUTH', 'zones', 'access/apps/ca')
     self.add('AUTH', 'zones', 'access/apps', 'ca')
     self.add('AUTH', 'zones', 'access/apps', 'user_policy_checks')
@@ -579,6 +588,7 @@ def accounts_access(self):
     self.add('AUTH', 'accounts', 'access/apps', 'revoke_tokens')
     self.add('AUTH', 'accounts', 'access/apps', 'user_policy_checks')
     self.add('AUTH', 'accounts', 'access/certificates')
+    self.add('AUTH', 'accounts', 'access/certificates/settings')
     self.add('AUTH', 'accounts', 'access/keys')
     self.add('AUTH', 'accounts', 'access/keys/rotate')
     self.add('VOID', 'accounts', 'access/logs')
@@ -602,6 +612,7 @@ def zones_waiting_rooms(self):
     self.add('AUTH', 'zones', 'waiting_rooms', 'rules')
     self.add('AUTH', 'zones', 'waiting_rooms', 'status')
     self.add('AUTH', 'zones', 'waiting_rooms/preview')
+    self.add('AUTH', 'zones', 'waiting_rooms/settings')
 
 def accounts_extras(self):
     """ extras """
@@ -622,6 +633,8 @@ def accounts_extras(self):
 
     self.add('AUTH', 'accounts', 'devices')
     self.add('AUTH', 'accounts', 'devices', 'override_codes')
+    self.add('AUTH', 'accounts', 'devices/dex_tests')
+    self.add('AUTH', 'accounts', 'devices/networks')
     self.add('AUTH', 'accounts', 'devices/policies')
     self.add('AUTH', 'accounts', 'devices/policy')
     self.add('AUTH', 'accounts', 'devices/policy', 'exclude')
@@ -636,6 +649,7 @@ def accounts_extras(self):
     self.add('AUTH', 'accounts', 'devices/settings')
     self.add('AUTH', 'accounts', 'devices/unrevoke')
 
+
     self.add('AUTH', 'accounts', 'dns_firewall')
     self.add('VOID', 'accounts', 'dns_firewall', 'dns_analytics')
     self.add('AUTH', 'accounts', 'dns_firewall', 'dns_analytics/report')
@@ -710,8 +724,11 @@ def zones_extras(self):
     self.add('VOID', 'zones', 'cache')
     self.add('AUTH', 'zones', 'cache/variants')
     self.add('AUTH', 'zones', 'cache/cache_reserve')
+    self.add('AUTH', 'zones', 'cache/regional_tiered_cache')
+    self.add('AUTH', 'zones', 'cache/tiered_cache_smart_topology_enable')
     self.add('AUTH', 'zones', 'managed_headers')
     self.add('AUTH', 'zones', 'page_shield')
+    self.add('AUTH', 'zones', 'page_shield/policies')
     self.add('AUTH', 'zones', 'page_shield/scripts')
     self.add('AUTH', 'zones', 'page_shield/connections')
     self.add('AUTH', 'zones', 'rulesets')
@@ -775,11 +792,49 @@ def radar(self):
     self.add('VOID', 'radar/annotations')
     self.add('AUTH', 'radar/annotations/outages')
     self.add('AUTH', 'radar/annotations/outages/locations')
+
+    self.add('VOID', 'radar/as112')
+    self.add('VOID', 'radar/as112/summary')
+    self.add('AUTH', 'radar/as112/summary/dnssec')
+    self.add('AUTH', 'radar/as112/summary/edns')
+    self.add('AUTH', 'radar/as112/summary/ip_version')
+    self.add('AUTH', 'radar/as112/summary/protocol')
+    self.add('AUTH', 'radar/as112/summary/query_type')
+    self.add('AUTH', 'radar/as112/summary/response_codes')
+    self.add('AUTH', 'radar/as112/timeseries')
+    self.add('AUTH', 'radar/as112/timeseries/dnssec')
+    self.add('AUTH', 'radar/as112/timeseries/edns')
+    self.add('AUTH', 'radar/as112/timeseries/ip_version')
+    self.add('AUTH', 'radar/as112/timeseries/protocol')
+    self.add('AUTH', 'radar/as112/timeseries/query_type')
+    self.add('AUTH', 'radar/as112/timeseries/response_codes')
+    self.add('VOID', 'radar/as112/top')
+    self.add('AUTH', 'radar/as112/top/locations')
+    self.add('AUTH', 'radar/as112/top/locations/dnssec')
+    self.add('AUTH', 'radar/as112/top/locations/edns')
+    self.add('AUTH', 'radar/as112/top/locations/ip_version')
+
     self.add('VOID', 'radar/attacks')
     self.add('VOID', 'radar/attacks/layer3')
     self.add('AUTH', 'radar/attacks/layer3/summary')
     self.add('AUTH', 'radar/attacks/layer3/timeseries')
     self.add('AUTH', 'radar/attacks/layer3/timeseries_groups')
+    self.add('AUTH', 'radar/attacks/layer3/summary/bitrate')
+    self.add('AUTH', 'radar/attacks/layer3/summary/duration')
+    self.add('AUTH', 'radar/attacks/layer3/summary/ip_version')
+    self.add('AUTH', 'radar/attacks/layer3/summary/protocol')
+    self.add('AUTH', 'radar/attacks/layer3/summary/vector')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/bitrate')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/duration')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/industry')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/ip_version')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/protocol')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/vector')
+    self.add('AUTH', 'radar/attacks/layer3/timeseries_groups/vertical')
+    self.add('VOID', 'radar/attacks/layer3/top')
+    self.add('AUTH', 'radar/attacks/layer3/top/industry')
+    self.add('AUTH', 'radar/attacks/layer3/top/vertical')
+
     self.add('VOID', 'radar/attacks/layer7')
     self.add('AUTH', 'radar/attacks/layer7/summary')
     self.add('AUTH', 'radar/attacks/layer7/timeseries')
@@ -791,6 +846,7 @@ def radar(self):
     self.add('VOID', 'radar/attacks/layer7/top/locations')
     self.add('AUTH', 'radar/attacks/layer7/top/locations/origin')
     self.add('AUTH', 'radar/attacks/layer7/top/locations/target')
+
     self.add('VOID', 'radar/bgp')
     self.add('VOID', 'radar/bgp/leaks')
     self.add('AUTH', 'radar/bgp/leaks/events')
@@ -798,16 +854,56 @@ def radar(self):
     self.add('VOID', 'radar/bgp/top')
     self.add('AUTH', 'radar/bgp/top/ases')
     self.add('AUTH', 'radar/bgp/top/prefixes')
+    self.add('VOID', 'radar/bgp/hijacks')
+    self.add('AUTH', 'radar/bgp/hijacks/events')
+
     self.add('AUTH', 'radar/datasets')
     self.add('AUTH', 'radar/datasets/download')
+
     self.add('VOID', 'radar/dns')
     self.add('VOID', 'radar/dns/top')
     self.add('AUTH', 'radar/dns/top/ases')
     self.add('AUTH', 'radar/dns/top/locations')
+
+    self.add('VOID', 'radar/email')
+    self.add('VOID', 'radar/email/security')
+    self.add('VOID', 'radar/email/security/summary')
+    self.add('AUTH', 'radar/email/security/summary/arc')
+    self.add('AUTH', 'radar/email/security/summary/dkim')
+    self.add('AUTH', 'radar/email/security/summary/dmarc')
+    self.add('AUTH', 'radar/email/security/summary/malicious')
+    self.add('AUTH', 'radar/email/security/summary/spam')
+    self.add('AUTH', 'radar/email/security/summary/spf')
+    self.add('AUTH', 'radar/email/security/summary/threat_category')
+    self.add('VOID', 'radar/email/security/timeseries')
+    self.add('AUTH', 'radar/email/security/timeseries/arc')
+    self.add('AUTH', 'radar/email/security/timeseries/dkim')
+    self.add('AUTH', 'radar/email/security/timeseries/dmarc')
+    self.add('AUTH', 'radar/email/security/timeseries/malicious')
+    self.add('AUTH', 'radar/email/security/timeseries/spam')
+    self.add('AUTH', 'radar/email/security/timeseries/spf')
+    self.add('AUTH', 'radar/email/security/timeseries/threat_category')
+    self.add('VOID', 'radar/email/security/top')
+    self.add('AUTH', 'radar/email/security/top/ases')
+    self.add('AUTH', 'radar/email/security/top/ases/arc')
+    self.add('AUTH', 'radar/email/security/top/ases/dkim')
+    self.add('AUTH', 'radar/email/security/top/ases/dmarc')
+    self.add('AUTH', 'radar/email/security/top/ases/malicious')
+    self.add('AUTH', 'radar/email/security/top/ases/spam')
+    self.add('AUTH', 'radar/email/security/top/ases/spf')
+    self.add('AUTH', 'radar/email/security/top/locations')
+    self.add('AUTH', 'radar/email/security/top/locations/arc')
+    self.add('AUTH', 'radar/email/security/top/locations/dkim')
+    self.add('AUTH', 'radar/email/security/top/locations/dmarc')
+    self.add('AUTH', 'radar/email/security/top/locations/malicious')
+    self.add('AUTH', 'radar/email/security/top/locations/spam')
+    self.add('AUTH', 'radar/email/security/top/locations/spf')
+
     self.add('VOID', 'radar/entities')
     self.add('AUTH', 'radar/entities/asns')
     self.add('AUTH', 'radar/entities/asns/ip')
     self.add('AUTH', 'radar/entities/locations')
+
     self.add('VOID', 'radar/http')
     self.add('VOID', 'radar/http/summary')
     self.add('AUTH', 'radar/http/summary/bot_class')
@@ -815,6 +911,7 @@ def radar(self):
     self.add('AUTH', 'radar/http/summary/http_protocol')
     self.add('AUTH', 'radar/http/summary/http_version')
     self.add('AUTH', 'radar/http/summary/ip_version')
+    self.add('AUTH', 'radar/http/summary/os')
     self.add('AUTH', 'radar/http/summary/tls_version')
     self.add('VOID', 'radar/http/timeseries')
     self.add('AUTH', 'radar/http/timeseries/bot_class')
@@ -824,6 +921,7 @@ def radar(self):
     self.add('AUTH', 'radar/http/timeseries/http_protocol')
     self.add('AUTH', 'radar/http/timeseries/http_version')
     self.add('AUTH', 'radar/http/timeseries/ip_version')
+    self.add('AUTH', 'radar/http/timeseries/os')
     self.add('AUTH', 'radar/http/timeseries/tls_version')
     self.add('VOID', 'radar/http/top')
     self.add('AUTH', 'radar/http/top/ases')
@@ -832,6 +930,7 @@ def radar(self):
     self.add('AUTH', 'radar/http/top/ases/http_protocol')
     self.add('AUTH', 'radar/http/top/ases/http_version')
     self.add('AUTH', 'radar/http/top/ases/ip_version')
+    self.add('AUTH', 'radar/http/top/ases/os')
     self.add('AUTH', 'radar/http/top/ases/tls_version')
     self.add('AUTH', 'radar/http/top/browsers')
     self.add('AUTH', 'radar/http/top/browser_families')
@@ -841,13 +940,22 @@ def radar(self):
     self.add('AUTH', 'radar/http/top/locations/http_protocol')
     self.add('AUTH', 'radar/http/top/locations/http_version')
     self.add('AUTH', 'radar/http/top/locations/ip_version')
+    self.add('AUTH', 'radar/http/top/locations/os')
     self.add('AUTH', 'radar/http/top/locations/tls_version')
+
     self.add('VOID', 'radar/netflows')
     self.add('AUTH', 'radar/netflows/timeseries')
     self.add('VOID', 'radar/netflows/top')
     self.add('AUTH', 'radar/netflows/top/ases')
     self.add('AUTH', 'radar/netflows/top/locations')
+
+    self.add('VOID', 'radar/performance')
+    self.add('VOID', 'radar/performance/iqi')
+    self.add('AUTH', 'radar/performance/iqi/summary')
+    self.add('AUTH', 'radar/performance/iqi/timeseries_groups')
+
     self.add('VOID', 'radar/ranking')
+    self.add('AUTH', 'radar/ranking/domain')
     self.add('AUTH', 'radar/ranking/timeseries')
     self.add('AUTH', 'radar/ranking/top')
     self.add('VOID', 'radar/search')
@@ -868,9 +976,21 @@ def from_developers(self):
 
     self.add('VOID', 'accounts', 'logpush')
     self.add('AUTH', 'accounts', 'logpush/jobs')
+    self.add('VOID', 'accounts', 'logpush/datasets')
+    self.add('AUTH', 'accounts', 'logpush/datasets', 'fields')
+    self.add('AUTH', 'accounts', 'logpush/datasets', 'jobs')
+    self.add('AUTH', 'accounts', 'logpush/ownership')
+    self.add('AUTH', 'accounts', 'logpush/ownership/validate')
+    self.add('VOID', 'accounts', 'logpush/validate')
+    self.add('VOID', 'accounts', 'logpush/validate/destination')
+    self.add('AUTH', 'accounts', 'logpush/validate/destination/exists')
+    self.add('AUTH', 'accounts', 'logpush/validate/origin')
 
     self.add('VOID', 'accounts', 'logs')
     self.add('AUTH', 'accounts', 'logs/retrieve')
+    self.add('VOID', 'accounts', 'logs/control')
+    self.add('VOID', 'accounts', 'logs/control/cmb')
+    self.add('AUTH', 'accounts', 'logs/control/cmb/config')
 
     self.add('VOID', 'accounts', 'magic/advanced_tcp_protection')
     self.add('VOID', 'accounts', 'magic/advanced_tcp_protection/configs')
@@ -926,3 +1046,16 @@ def from_developers(self):
     self.add('VOID', 'zones', 'rulesets/phases/http_request_firewall_managed')
     self.add('AUTH', 'zones', 'rulesets/phases/http_request_firewall_managed/entrypoint')
     self.add('AUTH', 'zones', 'rulesets/phases/http_request_firewall_managed/entrypoint/versions')
+
+    self.add('VOID', 'zones', 'certificate_authorities')
+    self.add('AUTH', 'zones', 'certificate_authorities/hostname_associations')
+    self.add('AUTH', 'zones', 'hold')
+
+    self.add('VOID', 'accounts', 'challenges')
+    self.add('AUTH', 'accounts', 'challenges/widgets')
+    self.add('AUTH', 'accounts', 'challenges/widgets', 'rotate_secret')
+    self.add('AUTH', 'accounts', 'mtls_certificates')
+    self.add('AUTH', 'accounts', 'mtls_certificates', 'associations')
+    self.add('VOID', 'accounts', 'request-tracer')
+    self.add('AUTH', 'accounts', 'request-tracer/trace')
+
